2. Building a photo gallery with CubicWeb — CubicWeb 3.11.0

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Tutorials »

# 2. Building a photo gallery with CubicWeb

## 2.1. Desired features

- basically a photo gallery
- photo stored on the file system and displayed dynamically through a web interface
- navigation through folder (album), tags, geographical zone, people on the picture... using facets
- advanced security (not everyone can see everything). More on this later.

- 2.1.1. Cube creation and schema definition
  - 2.1.1.1. Step 1: creating a new cube for my web site
  - 2.1.1.2. Step 2: pick building blocks into existing cubes
  - 2.1.1.3. Step 3: glue everything together in my cube’s schema
  - 2.1.1.4. Step 4: creating the instance
- 2.1.2. Security, testing and migration
  - 2.1.2.1. Step 1: configuring security into the schema
  - 2.1.2.2. Step 2: security propagation in hooks
  - 2.1.2.3. Step 3: testing our security
  - 2.1.2.4. Step 4: writing the migration script and migrating the instance
- 2.1.3. Storing images on the file-system
  - 2.1.3.1. Step 1: configuring the BytesFileSystem storage
  - 2.1.3.2. Step 2: importing some data into the instance
  - 2.1.3.3. Conclusion
- 2.1.4. Let’s make it more user friendly
  - 2.1.4.1. Step 1: let’s improve site’s usability for our visitors
  - 2.1.4.2. Step 2: providing a custom index page
  - 2.1.4.3. Step 3: more navigation improvments
  - 2.1.4.4. Step 4: preparing the release and migrating the instance
- 2.1.5. Building my photos web site with CubicWeb part V: let’s make it even more user friendly
  - 2.1.5.1. Step 1: tired of the default look?
  - 2.1.5.2. Step 2: configuring boxes
  - 2.1.5.3. Step 3: configuring facets
  - 2.1.5.4. Conclusion

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Tutorials »